@@ -5,13 +5,14 @@ from typing import Final
 
 class CA:
     Api: Final[str] = "api"
-
     Auth: Final[str] = "aut"
+    Ascending: Final[str] = "asc"  # in SQL
 
     Code: Final[str] = "cd"
     Count: Final[str] = "cnt"
 
     Data: Final[str] = "dt"
+    Descending: Final[str] = "desc"  # in SQL
     DescriptionFormatted: Final[str] = "desf"
     DescriptionId: Final[str] = "desid"
     DescriptionPlain: Final[str] = "desp"
@@ -26,6 +27,8 @@ class CA:
     Result: Final[str] = "ret"
 
     Signup: Final[str] = "sgu"
+    SortBy: Final[str] = "stby"
+    SortDirection: Final[str] = "stdr"
 
     Title: Final[str] = "tt"
     TitleId: Final[str] = "ttid"
